@@ -171,7 +171,7 @@ class MyTB(AbstractTB):
                               prefix,
                               posfile='POSCAR',
                               nls=True,
-                              groupby='spin'):
+                              groupby=None):
         """
         read tight binding model from a wannier function directory. 
         :param path: path
@@ -186,17 +186,17 @@ class MyTB(AbstractTB):
         atoms = read(os.path.join(path, posfile))
         cell = atoms.get_cell()
         xred = cell.scaled_positions(xcart)
-        if groupby == 'orbital':
+        if groupby == 'spin':
             norb = nbasis // 2
-            xtmp = np.copy(xred)
-            xred[:norb] = xtmp[::2]
-            xred[norb:] = xtmp[1::2]
+            xtmp = copy.deepcopy(xred)
+            xred[::2] = xtmp[:norb]
+            xred[1::2] = xtmp[norb:]
             for key, val in data.items():
                 dtmp = copy.deepcopy(val)
-                data[key][:norb, :norb] = dtmp[::2, ::2]
-                data[key][:norb, norb:] = dtmp[::2, 1::2]
-                data[key][norb:, :norb] = dtmp[1::2, ::2]
-                data[key][norb:, norb:] = dtmp[1::2, 1::2]
+                data[key][::2, ::2]   = dtmp[:norb, :norb]
+                data[key][::2, 1::2]  = dtmp[:norb, norb:]
+                data[key][1::2, ::2]  = dtmp[norb:, :norb]
+                data[key][1::2, 1::2] = dtmp[norb:, norb:]
         ind, positions = auto_assign_basis_name(xred, atoms)
         m = MyTB(nbasis=nbasis, data=data, positions=xred)
         nm = m.shift_position(positions)
@@ -290,11 +290,6 @@ class MyTB(AbstractTB):
         """
         The matrix P: P(i, j) = r(j)-r(i)
         """
-        #self.rjminusri = np.zeros((self.nbasis, self.nbasis, self.ndim),
-        #                          dtype=float)
-        #for i in range(self.nbasis):
-        #    for j in range(self.nbasis):
-        #        self.rjminusri[i, j] = self.xred[j] - self.xred[i]
         self.rjminusri = self.xred[None, :, :] - self.xred[:, None, :]
 
     def to_sparse(self):
@@ -521,13 +516,6 @@ class MyTB(AbstractTB):
                 ret.data[R][self.norb:, self.norb:] = mat
         return ret
 
-    #def plot_band(self, kpts, color='green', show=False):
-    #    evals, evecs = self.solve_all(kpts)
-    #    for i in range(self.nbasis):
-    #        plt.plot(evals[:, i], color=color)
-    #    if show():
-    #        plt.show()
-
     def validate(self):
         # make sure all R are 3d.
         for R in self.data.keys():
